==> grafana-alloy-debug-1.11.3-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.44.0/api/datadogV2/model_incident_type_object.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"fmt"

	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// IncidentTypeObject Incident type response data.
type IncidentTypeObject struct {
	// Incident type's attributes.
	Attributes *IncidentTypeAttributes `json:"attributes,omitempty"`
	// The incident type's ID.
	Id string `json:"id"`
	// Incident type resource type.
	Type IncidentTypeType `json:"type"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewIncidentTypeObject instantiates a new IncidentTypeObject object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewIncidentTypeObject(id string, typeVar IncidentTypeType) *IncidentTypeObject {
	this := IncidentTypeObject{}
	this.Id = id
	this.Type = typeVar
	return &this
}

// NewIncidentTypeObjectWithDefaults instantiates a new IncidentTypeObject object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewIncidentTypeObjectWithDefaults() *IncidentTypeObject {
	this := IncidentTypeObject{}
	var typeVar IncidentTypeType = INCIDENTTYPETYPE_INCIDENT_TYPES
	this.Type = typeVar
	return &this
}

// GetAttributes returns the Attributes field value if set, zero value otherwise.
func (o *IncidentTypeObject) GetAttributes() IncidentTypeAttributes {
	if o == nil || o.Attributes == nil {
		var ret IncidentTypeAttributes
		return ret
	}
	return *o.Attributes
}

// GetAttributesOk returns a tuple with the Attributes field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetAttributesOk() (*IncidentTypeAttributes, bool) {
	if o == nil || o.Attributes == nil {
		return nil, false
	}
	return o.Attributes, true
}

// HasAttributes returns a boolean if a field has been set.
func (o *IncidentTypeObject) HasAttributes() bool {
	return o != nil && o.Attributes != nil
}

// SetAttributes gets a reference to the given IncidentTypeAttributes and assigns it to the Attributes field.
func (o *IncidentTypeObject) SetAttributes(v IncidentTypeAttributes) {
	o.Attributes = &v
}

// GetId returns the Id field value.
func (o *IncidentTypeObject) GetId() string {
	if o == nil {
		var ret string
		return ret
	}
	return o.Id
}

// GetIdOk returns a tuple with the Id field value
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Id, true
}

// SetId sets field value.
func (o *IncidentTypeObject) SetId(v string) {
	o.Id = v
}

// GetType returns the Type field value.
func (o *IncidentTypeObject) GetType() IncidentTypeType {
	if o == nil {
		var ret IncidentTypeType
		return ret
	}
	return o.Type
}

// GetTypeOk returns a tuple with the Type field value
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetTypeOk() (*IncidentTypeType, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Type, true
}

// SetType sets field value.
func (o *IncidentTypeObject) SetType(v IncidentTypeType) {
	o.Type = v
}

// MarshalJSON serializes the struct using spec logic.
func (o IncidentTypeObject) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Attributes != nil {
		toSerialize["attributes"] = o.Attributes
	}
	toSerialize["id"] = o.Id
	toSerialize["type"] = o.Type

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *IncidentTypeObject) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Attributes *IncidentTypeAttributes `json:"attributes,omitempty"`
		Id         *string                 `json:"id"`
		Type       *IncidentTypeType       `json:"type"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	if all.Id == nil {
		return fmt.Errorf("required field id missing")
	}
	if all.Type == nil {
		return fmt.Errorf("required field type missing")
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"attributes", "id", "type"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Attributes != nil && all.Attributes.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Attributes = all.Attributes
	o.Id = *all.Id
	if !all.Type.IsValid() {
		hasInvalidField = true
	} else {
		o.Type = *all.Type
	}

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}

==> grafana-alloy-debug-1.12.1-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.48.0/api/datadogV2/model_incident_type_object.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"fmt"

	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// IncidentTypeObject Incident type response data.
type IncidentTypeObject struct {
	// Incident type's attributes.
	Attributes *IncidentTypeAttributes `json:"attributes,omitempty"`
	// The incident type's ID.
	Id string `json:"id"`
	// The incident type's resource relationships.
	Relationships *IncidentTypeRelationships `json:"relationships,omitempty"`
	// Incident type resource type.
	Type IncidentTypeType `json:"type"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewIncidentTypeObject instantiates a new IncidentTypeObject object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewIncidentTypeObject(id string, typeVar IncidentTypeType) *IncidentTypeObject {
	this := IncidentTypeObject{}
	this.Id = id
	this.Type = typeVar
	return &this
}

// NewIncidentTypeObjectWithDefaults instantiates a new IncidentTypeObject object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewIncidentTypeObjectWithDefaults() *IncidentTypeObject {
	this := IncidentTypeObject{}
	var typeVar IncidentTypeType = INCIDENTTYPETYPE_INCIDENT_TYPES
	this.Type = typeVar
	return &this
}

// GetAttributes returns the Attributes field value if set, zero value otherwise.
func (o *IncidentTypeObject) GetAttributes() IncidentTypeAttributes {
	if o == nil || o.Attributes == nil {
		var ret IncidentTypeAttributes
		return ret
	}
	return *o.Attributes
}

// GetAttributesOk returns a tuple with the Attributes field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetAttributesOk() (*IncidentTypeAttributes, bool) {
	if o == nil || o.Attributes == nil {
		return nil, false
	}
	return o.Attributes, true
}

// HasAttributes returns a boolean if a field has been set.
func (o *IncidentTypeObject) HasAttributes() bool {
	return o != nil && o.Attributes != nil
}

// SetAttributes gets a reference to the given IncidentTypeAttributes and assigns it to the Attributes field.
func (o *IncidentTypeObject) SetAttributes(v IncidentTypeAttributes) {
	o.Attributes = &v
}

// GetId returns the Id field value.
func (o *IncidentTypeObject) GetId() string {
	if o == nil {
		var ret string
		return ret
	}
	return o.Id
}

// GetIdOk returns a tuple with the Id field value
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Id, true
}

// SetId sets field value.
func (o *IncidentTypeObject) SetId(v string) {
	o.Id = v
}

// GetRelationships returns the Relationships field value if set, zero value otherwise.
func (o *IncidentTypeObject) GetRelationships() IncidentTypeRelationships {
	if o == nil || o.Relationships == nil {
		var ret IncidentTypeRelationships
		return ret
	}
	return *o.Relationships
}

// GetRelationshipsOk returns a tuple with the Relationships field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetRelationshipsOk() (*IncidentTypeRelationships, bool) {
	if o == nil || o.Relationships == nil {
		return nil, false
	}
	return o.Relationships, true
}

// HasRelationships returns a boolean if a field has been set.
func (o *IncidentTypeObject) HasRelationships() bool {
	return o != nil && o.Relationships != nil
}

// SetRelationships gets a reference to the given IncidentTypeRelationships and assigns it to the Relationships field.
func (o *IncidentTypeObject) SetRelationships(v IncidentTypeRelationships) {
	o.Relationships = &v
}

// GetType returns the Type field value.
func (o *IncidentTypeObject) GetType() IncidentTypeType {
	if o == nil {
		var ret IncidentTypeType
		return ret
	}
	return o.Type
}

// GetTypeOk returns a tuple with the Type field value
// and a boolean to check if the value has been set.
func (o *IncidentTypeObject) GetTypeOk() (*IncidentTypeType, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Type, true
}

// SetType sets field value.
func (o *IncidentTypeObject) SetType(v IncidentTypeType) {
	o.Type = v
}

// MarshalJSON serializes the struct using spec logic.
func (o IncidentTypeObject) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Attributes != nil {
		toSerialize["attributes"] = o.Attributes
	}
	toSerialize["id"] = o.Id
	if o.Relationships != nil {
		toSerialize["relationships"] = o.Relationships
	}
	toSerialize["type"] = o.Type

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *IncidentTypeObject) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Attributes    *IncidentTypeAttributes    `json:"attributes,omitempty"`
		Id            *string                    `json:"id"`
		Relationships *IncidentTypeRelationships `json:"relationships,omitempty"`
		Type          *IncidentTypeType          `json:"type"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	if all.Id == nil {
		return fmt.Errorf("required field id missing")
	}
	if all.Type == nil {
		return fmt.Errorf("required field type missing")
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"attributes", "id", "relationships", "type"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Attributes != nil && all.Attributes.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Attributes = all.Attributes
	o.Id = *all.Id
	if all.Relationships != nil && all.Relationships.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Relationships = all.Relationships
	if !all.Type.IsValid() {
		hasInvalidField = true
	} else {
		o.Type = *all.Type
	}

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}
